"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthService = void 0;
const UserRepository_1 = require("../Repositories/UserRepository");
const http_status_codes_1 = __importDefault(require("http-status-codes"));
const HttpResponse_1 = require("../Helpers/HttpResponse");
const Constants_1 = require("../Helpers/Constants");
const joi_1 = __importDefault(require("joi"));
/*Validation Schema*/
const signUpSchema = joi_1.default.object({
    name: joi_1.default.string().min(3).max(50).required(),
    email: joi_1.default.string().min(3).max(255).required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.EMAIL_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.EMAIL_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.EMAIL_NOT_EMPTY}`,
        "string.min": `${Constants_1.VALIDATION_MESSAGES.EMAIL_NOT_EMPTY}`,
        "string.max": `${Constants_1.VALIDATION_MESSAGES.EMAIL_NOT_EMPTY}`,
    }).email({
        minDomainSegments: 2,
        tlds: { allow: Constants_1.DOMAINS },
    }),
    speak: joi_1.default.string().required(),
    isActive: joi_1.default.string(),
    nationality: joi_1.default.number().required(),
    type: joi_1.default.string().required(),
    gender: joi_1.default.string(),
    isSocial: joi_1.default.boolean().required(),
    socialId: joi_1.default.when("isSocial", { is: true, then: joi_1.default.string().required() }),
    socialLoginType: joi_1.default.when("isSocial", {
        is: true,
        then: joi_1.default.string().required(),
    }),
    password: joi_1.default.when("isSocial", {
        is: false,
        then: joi_1.default.string()
            .alphanum()
            .min(6)
            .max(30)
            .pattern(new RegExp("^[a-zA-Z0-9]{3,30}$"))
            .required(),
    }),
    // confirmPassword: Joi.string().valid(Joi.ref('password')).required(),
});
const loginSchema = joi_1.default.object({
    email: joi_1.default.string().min(3).max(255).required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.EMAIL_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.EMAIL_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.EMAIL_NOT_EMPTY}`,
        "string.min": `${Constants_1.VALIDATION_MESSAGES.EMAIL_NOT_EMPTY}`,
        "string.max": `${Constants_1.VALIDATION_MESSAGES.EMAIL_NOT_EMPTY}`,
    }).email({
        minDomainSegments: 2,
        tlds: { allow: Constants_1.DOMAINS },
    }),
    isSocial: joi_1.default.boolean().required(),
    socialId: joi_1.default.when("isSocial", { is: true, then: joi_1.default.string().required() }),
    socialLoginType: joi_1.default.when("isSocial", {
        is: true,
        then: joi_1.default.string().required(),
    }),
    password: joi_1.default.when("isSocial", {
        is: false,
        then: joi_1.default.string()
            .alphanum()
            .min(6)
            .max(30)
            .pattern(new RegExp("^[a-zA-Z0-9]{3,30}$"))
            .required()
    }),
});
const deleteSchema = joi_1.default.object({
    id: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.USER_ID_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.USER_ID_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.USER_ID_NOT_EMPTY}`,
    }),
});
const forgotPasswordSchema = joi_1.default.object({
    email: joi_1.default.string().min(3).max(255).required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.EMAIL_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.EMAIL_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.EMAIL_NOT_EMPTY}`,
        "string.min": `${Constants_1.VALIDATION_MESSAGES.EMAIL_NOT_EMPTY}`,
        "string.max": `${Constants_1.VALIDATION_MESSAGES.EMAIL_NOT_EMPTY}`,
    }).email({
        minDomainSegments: 2,
        tlds: { allow: Constants_1.DOMAINS },
    }),
});
const emailVerifySchema = joi_1.default.object({
    email: joi_1.default.string().min(3).max(255).required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.EMAIL_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.EMAIL_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.EMAIL_NOT_EMPTY}`,
        "string.min": `${Constants_1.VALIDATION_MESSAGES.EMAIL_NOT_EMPTY}`,
        "string.max": `${Constants_1.VALIDATION_MESSAGES.EMAIL_NOT_EMPTY}`,
    }).email({
        minDomainSegments: 2,
        tlds: { allow: Constants_1.DOMAINS },
    }),
});
const phoneVerifySchema = joi_1.default.object({
    phone: joi_1.default.string().required().messages({
        "any.required": `${Constants_1.VALIDATION_MESSAGES.PHONE_REQUIRED}`,
        "string.base": `${Constants_1.VALIDATION_MESSAGES.PHONE_BASE}`,
        "string.empty": `${Constants_1.VALIDATION_MESSAGES.PHONE_NOT_EMPTY}`,
    }),
});
/*End Validation Schema*/
class AuthService {
    constructor() { }
    getUsers() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield UserRepository_1.UserRepository.getUsers();
        });
    }
    createUser(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield signUpSchema.validateAsync(req.body, { allowUnknown: true });
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
            return yield UserRepository_1.UserRepository.createUser(req);
        });
    }
    loginUser(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield loginSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
            return yield UserRepository_1.UserRepository.loginUser(req);
        });
    }
    deleteUser(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield deleteSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
            return yield UserRepository_1.UserRepository.deleteUser(req);
        });
    }
    emailVerification(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield emailVerifySchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
            return yield UserRepository_1.UserRepository.emailVerification(req);
        });
    }
    phoneVerification(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield phoneVerifySchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
            return yield UserRepository_1.UserRepository.phoneVerification(req);
        });
    }
    forgotPassword(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield forgotPasswordSchema.validateAsync(req.body);
            }
            catch (error) {
                const errors = error.details.map((x) => x.message);
                return HttpResponse_1.HttpResponse.error(http_status_codes_1.default.UNPROCESSABLE_ENTITY, errors);
            }
            return yield UserRepository_1.UserRepository.forgotPassword(req);
        });
    }
}
const authService = new AuthService();
exports.AuthService = authService;
